Class: Sendmux::Management::Generated::BalanceAutoTopup

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/balance_auto_topup.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BalanceAutoTopup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::BalanceAutoTopup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::BalanceAutoTopup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'monthly_limit')
    self.monthly_limit = attributes[:'monthly_limit']
  else
    self.monthly_limit = nil
  end

  if attributes.key?(:'monthly_used')
    self.monthly_used = attributes[:'monthly_used']
  else
    self.monthly_used = nil
  end

  if attributes.key?(:'threshold')
    self.threshold = attributes[:'threshold']
  else
    self.threshold = nil
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



18
19
20
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 18

def amount
  @amount
end

#enabledObject

Returns the value of attribute enabled.



20
21
22
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 20

def enabled
  @enabled
end

#monthly_limitObject

Returns the value of attribute monthly_limit.



22
23
24
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 22

def monthly_limit
  @monthly_limit
end

#monthly_usedObject

Returns the value of attribute monthly_used.



24
25
26
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 24

def monthly_used
  @monthly_used
end

#thresholdObject

Returns the value of attribute threshold.



26
27
28
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 26

def threshold
  @threshold
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 29

def self.attribute_map
  {
    :'amount' => :'amount',
    :'enabled' => :'enabled',
    :'monthly_limit' => :'monthly_limit',
    :'monthly_used' => :'monthly_used',
    :'threshold' => :'threshold'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
65
66
67
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 61

def self.openapi_nullable
  Set.new([
    :'amount',
    :'monthly_limit',
    :'threshold'
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 50

def self.openapi_types
  {
    :'amount' => :'String',
    :'enabled' => :'Boolean',
    :'monthly_limit' => :'String',
    :'monthly_used' => :'String',
    :'threshold' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
170
171
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      enabled == o.enabled &&
      monthly_limit == o.monthly_limit &&
      monthly_used == o.monthly_used &&
      threshold == o.threshold
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 181

def hash
  [amount, enabled, monthly_limit, monthly_used, threshold].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @monthly_used.nil?
    invalid_properties.push('invalid value for "monthly_used", monthly_used cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
138
139
# File 'lib/sendmux_management_generated/models/balance_auto_topup.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @enabled.nil?
  return false if @monthly_used.nil?
  true
end