Class: Sendmux::Management::Generated::DeliveryLogItem

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/delivery_log_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeliveryLogItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 161

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::DeliveryLogItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::DeliveryLogItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'accepted_recipient_count')
    self.accepted_recipient_count = attributes[:'accepted_recipient_count']
  else
    self.accepted_recipient_count = nil
  end

  if attributes.key?(:'attempts')
    self.attempts = attributes[:'attempts']
  else
    self.attempts = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'from_email')
    self.from_email = attributes[:'from_email']
  else
    self.from_email = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'message_id')
    self.message_id = attributes[:'message_id']
  else
    self.message_id = nil
  end

  if attributes.key?(:'provider_id')
    self.provider_id = attributes[:'provider_id']
  else
    self.provider_id = nil
  end

  if attributes.key?(:'provider_name')
    self.provider_name = attributes[:'provider_name']
  else
    self.provider_name = nil
  end

  if attributes.key?(:'recipient_count')
    self.recipient_count = attributes[:'recipient_count']
  else
    self.recipient_count = nil
  end

  if attributes.key?(:'rejected_recipient_count')
    self.rejected_recipient_count = attributes[:'rejected_recipient_count']
  else
    self.rejected_recipient_count = nil
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  else
    self.sent_at = nil
  end

  if attributes.key?(:'sent_from_email')
    self.sent_from_email = attributes[:'sent_from_email']
  else
    self.sent_from_email = nil
  end

  if attributes.key?(:'size_bytes')
    self.size_bytes = attributes[:'size_bytes']
  else
    self.size_bytes = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'status_reason')
    self.status_reason = attributes[:'status_reason']
  else
    self.status_reason = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'to_email')
    self.to_email = attributes[:'to_email']
  else
    self.to_email = nil
  end
end

Instance Attribute Details

#accepted_recipient_countObject

Recipient occurrences accepted by the provider, or null when no recipient snapshot exists



19
20
21
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 19

def accepted_recipient_count
  @accepted_recipient_count
end

#attemptsObject

Returns the value of attribute attempts.



21
22
23
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 21

def attempts
  @attempts
end

#created_atObject

ISO 8601 creation timestamp



24
25
26
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 24

def created_at
  @created_at
end

#from_emailObject

Returns the value of attribute from_email.



26
27
28
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 26

def from_email
  @from_email
end

#idObject

Log public ID



29
30
31
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 29

def id
  @id
end

#message_idObject

Email Message-ID header



32
33
34
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 32

def message_id
  @message_id
end

#provider_idObject

Provider public ID



35
36
37
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 35

def provider_id
  @provider_id
end

#provider_nameObject

Provider display name



38
39
40
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 38

def provider_name
  @provider_name
end

#recipient_countObject

Total recipient occurrences, or null when no recipient snapshot exists



41
42
43
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 41

def recipient_count
  @recipient_count
end

#rejected_recipient_countObject

Recipient occurrences rejected by the provider, or null when no recipient snapshot exists



44
45
46
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 44

def rejected_recipient_count
  @rejected_recipient_count
end

#sent_atObject

ISO 8601 timestamp when email was sent



47
48
49
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 47

def sent_at
  @sent_at
end

#sent_from_emailObject

The actual from address used for delivery after transformation. NULL if no transformation occurred or for older log entries.



50
51
52
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 50

def sent_from_email
  @sent_from_email
end

#size_bytesObject

Returns the value of attribute size_bytes.



52
53
54
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 52

def size_bytes
  @size_bytes
end

#statusObject

Returns the value of attribute status.



54
55
56
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 54

def status
  @status
end

#status_reasonObject

Returns the value of attribute status_reason.



56
57
58
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 56

def status_reason
  @status_reason
end

#subjectObject

Returns the value of attribute subject.



58
59
60
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 58

def subject
  @subject
end

#to_emailObject

Returns the value of attribute to_email.



60
61
62
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 60

def to_email
  @to_email
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



108
109
110
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 108

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



113
114
115
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 113

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 85

def self.attribute_map
  {
    :'accepted_recipient_count' => :'accepted_recipient_count',
    :'attempts' => :'attempts',
    :'created_at' => :'created_at',
    :'from_email' => :'from_email',
    :'id' => :'id',
    :'message_id' => :'message_id',
    :'provider_id' => :'provider_id',
    :'provider_name' => :'provider_name',
    :'recipient_count' => :'recipient_count',
    :'rejected_recipient_count' => :'rejected_recipient_count',
    :'sent_at' => :'sent_at',
    :'sent_from_email' => :'sent_from_email',
    :'size_bytes' => :'size_bytes',
    :'status' => :'status',
    :'status_reason' => :'status_reason',
    :'subject' => :'subject',
    :'to_email' => :'to_email'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 466

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 141

def self.openapi_nullable
  Set.new([
    :'accepted_recipient_count',
    :'from_email',
    :'message_id',
    :'provider_id',
    :'provider_name',
    :'recipient_count',
    :'rejected_recipient_count',
    :'sent_at',
    :'sent_from_email',
    :'size_bytes',
    :'status_reason',
    :'subject',
    :'to_email'
  ])
end

.openapi_typesObject

Attribute type mapping.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 118

def self.openapi_types
  {
    :'accepted_recipient_count' => :'Integer',
    :'attempts' => :'Float',
    :'created_at' => :'String',
    :'from_email' => :'String',
    :'id' => :'String',
    :'message_id' => :'String',
    :'provider_id' => :'String',
    :'provider_name' => :'String',
    :'recipient_count' => :'Integer',
    :'rejected_recipient_count' => :'Integer',
    :'sent_at' => :'String',
    :'sent_from_email' => :'String',
    :'size_bytes' => :'Float',
    :'status' => :'String',
    :'status_reason' => :'String',
    :'subject' => :'String',
    :'to_email' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 429

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      accepted_recipient_count == o.accepted_recipient_count &&
      attempts == o.attempts &&
      created_at == o.created_at &&
      from_email == o.from_email &&
      id == o.id &&
      message_id == o.message_id &&
      provider_id == o.provider_id &&
      provider_name == o.provider_name &&
      recipient_count == o.recipient_count &&
      rejected_recipient_count == o.rejected_recipient_count &&
      sent_at == o.sent_at &&
      sent_from_email == o.sent_from_email &&
      size_bytes == o.size_bytes &&
      status == o.status &&
      status_reason == o.status_reason &&
      subject == o.subject &&
      to_email == o.to_email
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


453
454
455
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 453

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



459
460
461
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 459

def hash
  [accepted_recipient_count, attempts, created_at, from_email, id, message_id, provider_id, provider_name, recipient_count, rejected_recipient_count, sent_at, sent_from_email, size_bytes, status, status_reason, subject, to_email].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 280

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @accepted_recipient_count > 50
    invalid_properties.push('invalid value for "accepted_recipient_count", must be smaller than or equal to 50.')
  end

  if @accepted_recipient_count < 0
    invalid_properties.push('invalid value for "accepted_recipient_count", must be greater than or equal to 0.')
  end

  if @attempts.nil?
    invalid_properties.push('invalid value for "attempts", attempts cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @recipient_count > 50
    invalid_properties.push('invalid value for "recipient_count", must be smaller than or equal to 50.')
  end

  if @recipient_count < 0
    invalid_properties.push('invalid value for "recipient_count", must be greater than or equal to 0.')
  end

  if @rejected_recipient_count > 50
    invalid_properties.push('invalid value for "rejected_recipient_count", must be smaller than or equal to 50.')
  end

  if @rejected_recipient_count < 0
    invalid_properties.push('invalid value for "rejected_recipient_count", must be greater than or equal to 0.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 488

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 328

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @accepted_recipient_count > 50
  return false if @accepted_recipient_count < 0
  return false if @attempts.nil?
  return false if @created_at.nil?
  return false if @id.nil?
  return false if @recipient_count > 50
  return false if @recipient_count < 0
  return false if @rejected_recipient_count > 50
  return false if @rejected_recipient_count < 0
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["pending", "sent", "failed", "rejected", "unknown_default_open_api"])
  return false unless status_validator.valid?(@status)
  true
end