Class: Sendmux::Management::Generated::DomainFiltersApi
- Inherits:
-
Object
- Object
- Sendmux::Management::Generated::DomainFiltersApi
- Defined in:
- lib/sendmux_management_generated/api/domain_filters_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ DomainFiltersApi
constructor
A new instance of DomainFiltersApi.
-
#management_get_domain_filters(public_id, opts = {}) ⇒ FilterStateResponse
Get domain-wide sender filters Returns the current sender-filter mode and rule set applied to every mailbox under this domain.
-
#management_get_domain_filters_with_http_info(public_id, opts = {}) ⇒ Array<(FilterStateResponse, Integer, Hash)>
Get domain-wide sender filters Returns the current sender-filter mode and rule set applied to every mailbox under this domain.
-
#management_set_domain_filters(public_id, opts = {}) ⇒ FilterStateResponse
Replace domain-wide sender filters Atomically replaces the sender-filter mode and rule set for an entire domain.
-
#management_set_domain_filters_with_http_info(public_id, opts = {}) ⇒ Array<(FilterStateResponse, Integer, Hash)>
Replace domain-wide sender filters Atomically replaces the sender-filter mode and rule set for an entire domain.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DomainFiltersApi
Returns a new instance of DomainFiltersApi.
19 20 21 |
# File 'lib/sendmux_management_generated/api/domain_filters_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/sendmux_management_generated/api/domain_filters_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#management_get_domain_filters(public_id, opts = {}) ⇒ FilterStateResponse
Get domain-wide sender filters Returns the current sender-filter mode and rule set applied to every mailbox under this domain. Per-mailbox rules take precedence at match time. Responses carry a weak ‘ETag` — send it as `If-None-Match` to skip the body when the filter set has not changed (returns `304 Not Modified`). The same ETag is the value to use in `If-Match` on the corresponding PUT for optimistic concurrency.
28 29 30 31 |
# File 'lib/sendmux_management_generated/api/domain_filters_api.rb', line 28 def management_get_domain_filters(public_id, opts = {}) data, _status_code, _headers = management_get_domain_filters_with_http_info(public_id, opts) data end |
#management_get_domain_filters_with_http_info(public_id, opts = {}) ⇒ Array<(FilterStateResponse, Integer, Hash)>
Get domain-wide sender filters Returns the current sender-filter mode and rule set applied to every mailbox under this domain. Per-mailbox rules take precedence at match time. Responses carry a weak `ETag` — send it as `If-None-Match` to skip the body when the filter set has not changed (returns `304 Not Modified`). The same ETag is the value to use in `If-Match` on the corresponding PUT for optimistic concurrency.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/sendmux_management_generated/api/domain_filters_api.rb', line 39 def management_get_domain_filters_with_http_info(public_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainFiltersApi.management_get_domain_filters ...' end # verify the required parameter 'public_id' is set if @api_client.config.client_side_validation && public_id.nil? fail ArgumentError, "Missing the required parameter 'public_id' when calling DomainFiltersApi.management_get_domain_filters" end # resource path local_var_path = '/domains/{public_id}/filters'.sub('{public_id}', CGI.escape(public_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'FilterStateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"DomainFiltersApi.management_get_domain_filters", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainFiltersApi#management_get_domain_filters\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#management_set_domain_filters(public_id, opts = {}) ⇒ FilterStateResponse
Replace domain-wide sender filters Atomically replaces the sender-filter mode and rule set for an entire domain. Applies to every mailbox under the domain unless that mailbox has its own per-mailbox rules (which take precedence). Maximum 1000 rules per request. For optimistic concurrency, send ‘If-Match: <etag>` using the ETag from a prior GET. A mismatched `If-Match` returns `409 conflict` (the server’s ETag is echoed back so you can decide whether to re-fetch). Responses carry the new ETag so chained edits can pipeline without a re-GET.
95 96 97 98 |
# File 'lib/sendmux_management_generated/api/domain_filters_api.rb', line 95 def management_set_domain_filters(public_id, opts = {}) data, _status_code, _headers = management_set_domain_filters_with_http_info(public_id, opts) data end |
#management_set_domain_filters_with_http_info(public_id, opts = {}) ⇒ Array<(FilterStateResponse, Integer, Hash)>
Replace domain-wide sender filters Atomically replaces the sender-filter mode and rule set for an entire domain. Applies to every mailbox under the domain unless that mailbox has its own per-mailbox rules (which take precedence). Maximum 1000 rules per request. For optimistic concurrency, send `If-Match: <etag>` using the ETag from a prior GET. A mismatched `If-Match` returns `409 conflict` (the server's ETag is echoed back so you can decide whether to re-fetch). Responses carry the new ETag so chained edits can pipeline without a re-GET.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/sendmux_management_generated/api/domain_filters_api.rb', line 107 def management_set_domain_filters_with_http_info(public_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DomainFiltersApi.management_set_domain_filters ...' end # verify the required parameter 'public_id' is set if @api_client.config.client_side_validation && public_id.nil? fail ArgumentError, "Missing the required parameter 'public_id' when calling DomainFiltersApi.management_set_domain_filters" end # resource path local_var_path = '/domains/{public_id}/filters'.sub('{public_id}', CGI.escape(public_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'If-Match'] = opts[:'if_match'] if !opts[:'if_match'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'set_filter_state_body']) # return_type return_type = opts[:debug_return_type] || 'FilterStateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"DomainFiltersApi.management_set_domain_filters", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DomainFiltersApi#management_set_domain_filters\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |