Class: Sendmux::Management::Generated::EmailsApi
- Inherits:
-
Object
- Object
- Sendmux::Management::Generated::EmailsApi
- Defined in:
- lib/sendmux_management_generated/api/emails_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ EmailsApi
constructor
A new instance of EmailsApi.
-
#management_get_email_log(public_id, opts = {}) ⇒ DeliveryLogItemResponse
Get delivery log Returns a single delivery log by its public ID.
-
#management_get_email_log_with_http_info(public_id, opts = {}) ⇒ Array<(DeliveryLogItemResponse, Integer, Hash)>
Get delivery log Returns a single delivery log by its public ID.
-
#management_get_email_metrics(opts = {}) ⇒ EmailMetricsResponse
Get email metrics Returns aggregated email delivery counts with flexible time windowing and comparison period.
-
#management_get_email_metrics_with_http_info(opts = {}) ⇒ Array<(EmailMetricsResponse, Integer, Hash)>
Get email metrics Returns aggregated email delivery counts with flexible time windowing and comparison period.
-
#management_list_email_logs(opts = {}) ⇒ DeliveryLogItemCursorListResponse
List delivery logs Returns paginated delivery logs with cursor-based pagination and filters.
-
#management_list_email_logs_with_http_info(opts = {}) ⇒ Array<(DeliveryLogItemCursorListResponse, Integer, Hash)>
List delivery logs Returns paginated delivery logs with cursor-based pagination and filters.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/sendmux_management_generated/api/emails_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#management_get_email_log(public_id, opts = {}) ⇒ DeliveryLogItemResponse
Get delivery log Returns a single delivery log by its public ID. Responses carry a weak ‘ETag` header — send it back as `If-None-Match` on the next request and the server will return `304 Not Modified` (no body) when the log has not changed. Logs in a terminal status (sent/failed/rejected) stop changing, so 304 replay is a real bandwidth win on repeated polls.
28 29 30 31 |
# File 'lib/sendmux_management_generated/api/emails_api.rb', line 28 def management_get_email_log(public_id, opts = {}) data, _status_code, _headers = management_get_email_log_with_http_info(public_id, opts) data end |
#management_get_email_log_with_http_info(public_id, opts = {}) ⇒ Array<(DeliveryLogItemResponse, Integer, Hash)>
Get delivery log Returns a single delivery log by its public ID. Responses carry a weak `ETag` header — send it back as `If-None-Match` on the next request and the server will return `304 Not Modified` (no body) when the log has not changed. Logs in a terminal status (sent/failed/rejected) stop changing, so 304 replay is a real bandwidth win on repeated polls.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/sendmux_management_generated/api/emails_api.rb', line 39 def management_get_email_log_with_http_info(public_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailsApi.management_get_email_log ...' end # verify the required parameter 'public_id' is set if @api_client.config.client_side_validation && public_id.nil? fail ArgumentError, "Missing the required parameter 'public_id' when calling EmailsApi.management_get_email_log" end # resource path local_var_path = '/emails/logs/{public_id}'.sub('{public_id}', CGI.escape(public_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeliveryLogItemResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"EmailsApi.management_get_email_log", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsApi#management_get_email_log\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#management_get_email_metrics(opts = {}) ⇒ EmailMetricsResponse
Get email metrics Returns aggregated email delivery counts with flexible time windowing and comparison period.
97 98 99 100 |
# File 'lib/sendmux_management_generated/api/emails_api.rb', line 97 def management_get_email_metrics(opts = {}) data, _status_code, _headers = management_get_email_metrics_with_http_info(opts) data end |
#management_get_email_metrics_with_http_info(opts = {}) ⇒ Array<(EmailMetricsResponse, Integer, Hash)>
Get email metrics Returns aggregated email delivery counts with flexible time windowing and comparison period.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/sendmux_management_generated/api/emails_api.rb', line 111 def management_get_email_metrics_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailsApi.management_get_email_metrics ...' end allowable_values = ["24h", "7d", "30d", "unknown_default_open_api"] if @api_client.config.client_side_validation && opts[:'window'] && !allowable_values.include?(opts[:'window']) fail ArgumentError, "invalid value for \"window\", must be one of #{allowable_values}" end allowable_values = ["hourly", "daily", "unknown_default_open_api"] if @api_client.config.client_side_validation && opts[:'granularity'] && !allowable_values.include?(opts[:'granularity']) fail ArgumentError, "invalid value for \"granularity\", must be one of #{allowable_values}" end # resource path local_var_path = '/emails/metrics' # query parameters query_params = opts[:query_params] || {} query_params[:'window'] = opts[:'window'] if !opts[:'window'].nil? query_params[:'from_date'] = opts[:'from_date'] if !opts[:'from_date'].nil? query_params[:'to_date'] = opts[:'to_date'] if !opts[:'to_date'].nil? query_params[:'granularity'] = opts[:'granularity'] if !opts[:'granularity'].nil? query_params[:'provider_id'] = opts[:'provider_id'] if !opts[:'provider_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EmailMetricsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"EmailsApi.management_get_email_metrics", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsApi#management_get_email_metrics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#management_list_email_logs(opts = {}) ⇒ DeliveryLogItemCursorListResponse
List delivery logs Returns paginated delivery logs with cursor-based pagination and filters.
179 180 181 182 |
# File 'lib/sendmux_management_generated/api/emails_api.rb', line 179 def management_list_email_logs(opts = {}) data, _status_code, _headers = management_list_email_logs_with_http_info(opts) data end |
#management_list_email_logs_with_http_info(opts = {}) ⇒ Array<(DeliveryLogItemCursorListResponse, Integer, Hash)>
List delivery logs Returns paginated delivery logs with cursor-based pagination and filters.
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/sendmux_management_generated/api/emails_api.rb', line 195 def management_list_email_logs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailsApi.management_list_email_logs ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling EmailsApi.management_list_email_logs, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling EmailsApi.management_list_email_logs, must be greater than or equal to 1.' end allowable_values = ["pending", "sent", "failed", "rejected", "unknown_default_open_api"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end # resource path local_var_path = '/emails/logs' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'from_date'] = opts[:'from_date'] if !opts[:'from_date'].nil? query_params[:'to_date'] = opts[:'to_date'] if !opts[:'to_date'].nil? query_params[:'provider_id'] = opts[:'provider_id'] if !opts[:'provider_id'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeliveryLogItemCursorListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"EmailsApi.management_list_email_logs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsApi#management_list_email_logs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |