Class: Sendmux::Management::Generated::InboxesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/sendmux_management_generated/api/inboxes_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ InboxesApi

Returns a new instance of InboxesApi.



19
20
21
# File 'lib/sendmux_management_generated/api/inboxes_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/sendmux_management_generated/api/inboxes_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#management_get_inbox_log(public_id, opts = {}) ⇒ IncomingLogItemResponse

Get incoming log Returns one incoming message log by public ID.

Parameters:

  • public_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/sendmux_management_generated/api/inboxes_api.rb', line 27

def management_get_inbox_log(public_id, opts = {})
  data, _status_code, _headers = management_get_inbox_log_with_http_info(public_id, opts)
  data
end

#management_get_inbox_log_with_http_info(public_id, opts = {}) ⇒ Array<(IncomingLogItemResponse, Integer, Hash)>

Get incoming log Returns one incoming message log by public ID.

Parameters:

  • public_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(IncomingLogItemResponse, Integer, Hash)>)

    IncomingLogItemResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/sendmux_management_generated/api/inboxes_api.rb', line 37

def management_get_inbox_log_with_http_info(public_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: InboxesApi.management_get_inbox_log ...'
  end
  # verify the required parameter 'public_id' is set
  if @api_client.config.client_side_validation && public_id.nil?
    fail ArgumentError, "Missing the required parameter 'public_id' when calling InboxesApi.management_get_inbox_log"
  end
  # resource path
  local_var_path = '/inboxes/logs/{public_id}'.sub('{public_id}', CGI.escape(public_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IncomingLogItemResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"InboxesApi.management_get_inbox_log",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: InboxesApi#management_get_inbox_log\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#management_list_inbox_logs(opts = {}) ⇒ IncomingLogItemCursorListResponse

List incoming logs Returns paginated incoming message logs for billing accountability.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)
  • :cursor (String)
  • :mailbox_id (String)
  • :event_type (String)
  • :from_date (String)
  • :to_date (String)
  • :search (String)

Returns:



96
97
98
99
# File 'lib/sendmux_management_generated/api/inboxes_api.rb', line 96

def management_list_inbox_logs(opts = {})
  data, _status_code, _headers = management_list_inbox_logs_with_http_info(opts)
  data
end

#management_list_inbox_logs_with_http_info(opts = {}) ⇒ Array<(IncomingLogItemCursorListResponse, Integer, Hash)>

List incoming logs Returns paginated incoming message logs for billing accountability.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)
  • :cursor (String)
  • :mailbox_id (String)
  • :event_type (String)
  • :from_date (String)
  • :to_date (String)
  • :search (String)

Returns:



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/sendmux_management_generated/api/inboxes_api.rb', line 112

def management_list_inbox_logs_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: InboxesApi.management_list_inbox_logs ...'
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling InboxesApi.management_list_inbox_logs, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling InboxesApi.management_list_inbox_logs, must be greater than or equal to 1.'
  end

  allowable_values = ["message.received", "message.received.spam", "unknown_default_open_api"]
  if @api_client.config.client_side_validation && opts[:'event_type'] && !allowable_values.include?(opts[:'event_type'])
    fail ArgumentError, "invalid value for \"event_type\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/inboxes/logs'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil?
  query_params[:'mailbox_id'] = opts[:'mailbox_id'] if !opts[:'mailbox_id'].nil?
  query_params[:'event_type'] = opts[:'event_type'] if !opts[:'event_type'].nil?
  query_params[:'from_date'] = opts[:'from_date'] if !opts[:'from_date'].nil?
  query_params[:'to_date'] = opts[:'to_date'] if !opts[:'to_date'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IncomingLogItemCursorListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"InboxesApi.management_list_inbox_logs",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: InboxesApi#management_list_inbox_logs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end