Class: Sendmux::Management::Generated::MailboxDomainDnsRecords

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxDomainDnsRecords

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::MailboxDomainDnsRecords` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::MailboxDomainDnsRecords`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'dkim')
    if (value = attributes[:'dkim']).is_a?(Array)
      self.dkim = value
    end
  else
    self.dkim = nil
  end

  if attributes.key?(:'dmarc')
    self.dmarc = attributes[:'dmarc']
  else
    self.dmarc = nil
  end

  if attributes.key?(:'mx')
    if (value = attributes[:'mx']).is_a?(Array)
      self.mx = value
    end
  else
    self.mx = nil
  end

  if attributes.key?(:'spf')
    self.spf = attributes[:'spf']
  else
    self.spf = nil
  end

  if attributes.key?(:'verification')
    self.verification = attributes[:'verification']
  else
    self.verification = nil
  end
end

Instance Attribute Details

#dkimObject

Three SES DKIM CNAME records



19
20
21
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 19

def dkim
  @dkim
end

#dmarcObject

DMARC enforcement record (quarantine, no reporting)



22
23
24
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 22

def dmarc
  @dmarc
end

#mxObject

MX records the customer must place. All point at Sendmux’s inbound mail servers.



25
26
27
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 25

def mx
  @mx
end

#spfObject

Returns the value of attribute spf.



27
28
29
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 27

def spf
  @spf
end

#verificationObject

Ownership-proof TXT record (Sendmux-specific)



30
31
32
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 30

def verification
  @verification
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 33

def self.attribute_map
  {
    :'dkim' => :'dkim',
    :'dmarc' => :'dmarc',
    :'mx' => :'mx',
    :'spf' => :'spf',
    :'verification' => :'verification'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 54

def self.openapi_types
  {
    :'dkim' => :'Array<MailboxDomainNameValueRecord>',
    :'dmarc' => :'MailboxDomainNameValueRecord',
    :'mx' => :'Array<MailboxDomainMxRecord>',
    :'spf' => :'MailboxDomainNameValueRecord',
    :'verification' => :'MailboxDomainNameValueRecord'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      dkim == o.dkim &&
      dmarc == o.dmarc &&
      mx == o.mx &&
      spf == o.spf &&
      verification == o.verification
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 231

def hash
  [dkim, dmarc, mx, spf, verification].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 123

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @dkim.nil?
    invalid_properties.push('invalid value for "dkim", dkim cannot be nil.')
  end

  if @dmarc.nil?
    invalid_properties.push('invalid value for "dmarc", dmarc cannot be nil.')
  end

  if @mx.nil?
    invalid_properties.push('invalid value for "mx", mx cannot be nil.')
  end

  if @spf.nil?
    invalid_properties.push('invalid value for "spf", spf cannot be nil.')
  end

  if @verification.nil?
    invalid_properties.push('invalid value for "verification", verification cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



151
152
153
154
155
156
157
158
159
# File 'lib/sendmux_management_generated/models/mailbox_domain_dns_records.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @dkim.nil?
  return false if @dmarc.nil?
  return false if @mx.nil?
  return false if @spf.nil?
  return false if @verification.nil?
  true
end