Class: Sendmux::Management::Generated::MailboxDomainVerifyResult
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Management::Generated::MailboxDomainVerifyResult
- Defined in:
- lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#checks ⇒ Object
Returns the value of attribute checks.
-
#ses_dkim_signing_enabled ⇒ Object
Whether Amazon SES DKIM signing is enabled.
-
#ses_dkim_status ⇒ Object
Latest Amazon SES DKIM status.
-
#ses_identity_checked_at ⇒ Object
ISO 8601 time of this SES identity check.
-
#ses_identity_verification_status ⇒ Object
Latest Amazon SES identity status.
-
#ses_mail_from_status ⇒ Object
Latest Amazon SES MAIL FROM status.
-
#ses_verified_for_sending ⇒ Object
Whether Amazon SES permits identity sending.
-
#status ⇒ Object
Post-check verification status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxDomainVerifyResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxDomainVerifyResult
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::MailboxDomainVerifyResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::MailboxDomainVerifyResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'checks') self.checks = attributes[:'checks'] else self.checks = nil end if attributes.key?(:'ses_dkim_signing_enabled') self.ses_dkim_signing_enabled = attributes[:'ses_dkim_signing_enabled'] else self.ses_dkim_signing_enabled = nil end if attributes.key?(:'ses_dkim_status') self.ses_dkim_status = attributes[:'ses_dkim_status'] else self.ses_dkim_status = nil end if attributes.key?(:'ses_identity_checked_at') self.ses_identity_checked_at = attributes[:'ses_identity_checked_at'] else self.ses_identity_checked_at = nil end if attributes.key?(:'ses_identity_verification_status') self.ses_identity_verification_status = attributes[:'ses_identity_verification_status'] else self.ses_identity_verification_status = nil end if attributes.key?(:'ses_mail_from_status') self.ses_mail_from_status = attributes[:'ses_mail_from_status'] else self.ses_mail_from_status = nil end if attributes.key?(:'ses_verified_for_sending') self.ses_verified_for_sending = attributes[:'ses_verified_for_sending'] else self.ses_verified_for_sending = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end end |
Instance Attribute Details
#checks ⇒ Object
Returns the value of attribute checks.
18 19 20 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 18 def checks @checks end |
#ses_dkim_signing_enabled ⇒ Object
Whether Amazon SES DKIM signing is enabled
21 22 23 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 21 def ses_dkim_signing_enabled @ses_dkim_signing_enabled end |
#ses_dkim_status ⇒ Object
Latest Amazon SES DKIM status
24 25 26 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 24 def ses_dkim_status @ses_dkim_status end |
#ses_identity_checked_at ⇒ Object
ISO 8601 time of this SES identity check
27 28 29 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 27 def ses_identity_checked_at @ses_identity_checked_at end |
#ses_identity_verification_status ⇒ Object
Latest Amazon SES identity status
30 31 32 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 30 def ses_identity_verification_status @ses_identity_verification_status end |
#ses_mail_from_status ⇒ Object
Latest Amazon SES MAIL FROM status
33 34 35 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 33 def ses_mail_from_status @ses_mail_from_status end |
#ses_verified_for_sending ⇒ Object
Whether Amazon SES permits identity sending
36 37 38 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 36 def ses_verified_for_sending @ses_verified_for_sending end |
#status ⇒ Object
Post-check verification status
39 40 41 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 39 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 64 def self.attribute_map { :'checks' => :'checks', :'ses_dkim_signing_enabled' => :'ses_dkim_signing_enabled', :'ses_dkim_status' => :'ses_dkim_status', :'ses_identity_checked_at' => :'ses_identity_checked_at', :'ses_identity_verification_status' => :'ses_identity_verification_status', :'ses_mail_from_status' => :'ses_mail_from_status', :'ses_verified_for_sending' => :'ses_verified_for_sending', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 339 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 88 def self.openapi_types { :'checks' => :'MailboxDomainVerifyChecks', :'ses_dkim_signing_enabled' => :'Boolean', :'ses_dkim_status' => :'String', :'ses_identity_checked_at' => :'String', :'ses_identity_verification_status' => :'String', :'ses_mail_from_status' => :'String', :'ses_verified_for_sending' => :'Boolean', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 311 def ==(o) return true if self.equal?(o) self.class == o.class && checks == o.checks && ses_dkim_signing_enabled == o.ses_dkim_signing_enabled && ses_dkim_status == o.ses_dkim_status && ses_identity_checked_at == o.ses_identity_checked_at && ses_identity_verification_status == o.ses_identity_verification_status && ses_mail_from_status == o.ses_mail_from_status && ses_verified_for_sending == o.ses_verified_for_sending && status == o.status end |
#eql?(o) ⇒ Boolean
326 327 328 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 326 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
332 333 334 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 332 def hash [checks, ses_dkim_signing_enabled, ses_dkim_status, ses_identity_checked_at, ses_identity_verification_status, ses_mail_from_status, ses_verified_for_sending, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 174 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @checks.nil? invalid_properties.push('invalid value for "checks", checks cannot be nil.') end if @ses_dkim_signing_enabled.nil? invalid_properties.push('invalid value for "ses_dkim_signing_enabled", ses_dkim_signing_enabled cannot be nil.') end if @ses_dkim_status.nil? invalid_properties.push('invalid value for "ses_dkim_status", ses_dkim_status cannot be nil.') end if @ses_identity_checked_at.nil? invalid_properties.push('invalid value for "ses_identity_checked_at", ses_identity_checked_at cannot be nil.') end if @ses_identity_verification_status.nil? invalid_properties.push('invalid value for "ses_identity_verification_status", ses_identity_verification_status cannot be nil.') end if @ses_mail_from_status.nil? invalid_properties.push('invalid value for "ses_mail_from_status", ses_mail_from_status cannot be nil.') end if @ses_verified_for_sending.nil? invalid_properties.push('invalid value for "ses_verified_for_sending", ses_verified_for_sending cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 361 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/sendmux_management_generated/models/mailbox_domain_verify_result.rb', line 214 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @checks.nil? return false if @ses_dkim_signing_enabled.nil? return false if @ses_dkim_status.nil? return false if @ses_identity_checked_at.nil? return false if @ses_identity_verification_status.nil? return false if @ses_mail_from_status.nil? return false if @ses_verified_for_sending.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["verified", "pending", "failed", "unknown_default_open_api"]) return false unless status_validator.valid?(@status) true end |