Class: Sendmux::Management::Generated::ManagementCreateMailboxRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/management_create_mailbox_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ManagementCreateMailboxRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::ManagementCreateMailboxRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::ManagementCreateMailboxRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'quota_bytes')
    self.quota_bytes = attributes[:'quota_bytes']
  end

  if attributes.key?(:'send_scope')
    self.send_scope = attributes[:'send_scope']
  end
end

Instance Attribute Details

#display_nameObject

Returns the value of attribute display_name.



18
19
20
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 18

def display_name
  @display_name
end

#emailObject

Returns the value of attribute email.



20
21
22
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 20

def email
  @email
end

#quota_bytesObject

Storage quota in bytes. Allowed values: 1073741824 (1 GB), 5368709120 (5 GB), 53687091200 (50 GB).



23
24
25
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 23

def quota_bytes
  @quota_bytes
end

#send_scopeObject

Returns the value of attribute send_scope.



25
26
27
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 25

def send_scope
  @send_scope
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 28

def self.attribute_map
  {
    :'display_name' => :'display_name',
    :'email' => :'email',
    :'quota_bytes' => :'quota_bytes',
    :'send_scope' => :'send_scope'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
61
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 58

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 48

def self.openapi_types
  {
    :'display_name' => :'String',
    :'email' => :'String',
    :'quota_bytes' => :'Integer',
    :'send_scope' => :'ManagementCreateMailboxRequestSendScope'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      display_name == o.display_name &&
      email == o.email &&
      quota_bytes == o.quota_bytes &&
      send_scope == o.send_scope
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



212
213
214
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 212

def hash
  [display_name, email, quota_bytes, send_scope].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 100

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@display_name.nil? && @display_name.to_s.length > 254
    invalid_properties.push('invalid value for "display_name", the character length must be smaller than or equal to 254.')
  end

  if !@display_name.nil? && @display_name.to_s.length < 1
    invalid_properties.push('invalid value for "display_name", the character length must be greater than or equal to 1.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @email.to_s.length > 254
    invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 254.')
  end

  if @email.to_s.length < 5
    invalid_properties.push('invalid value for "email", the character length must be greater than or equal to 5.')
  end

  if !@quota_bytes.nil? && @quota_bytes < 1
    invalid_properties.push('invalid value for "quota_bytes", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
137
138
139
140
141
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@display_name.nil? && @display_name.to_s.length > 254
  return false if !@display_name.nil? && @display_name.to_s.length < 1
  return false if @email.nil?
  return false if @email.to_s.length > 254
  return false if @email.to_s.length < 5
  return false if !@quota_bytes.nil? && @quota_bytes < 1
  true
end