Class: Sendmux::Management::Generated::ManagementCreateMailboxRequestSendScope
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Management::Generated::ManagementCreateMailboxRequestSendScope
- Defined in:
- lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#group_public_ids ⇒ Object
Returns the value of attribute group_public_ids.
-
#provider_public_ids ⇒ Object
Returns the value of attribute provider_public_ids.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementCreateMailboxRequestSendScope
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ManagementCreateMailboxRequestSendScope
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::ManagementCreateMailboxRequestSendScope` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::ManagementCreateMailboxRequestSendScope`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'group_public_ids') if (value = attributes[:'group_public_ids']).is_a?(Array) self.group_public_ids = value end end if attributes.key?(:'provider_public_ids') if (value = attributes[:'provider_public_ids']).is_a?(Array) self.provider_public_ids = value end end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end end |
Instance Attribute Details
#group_public_ids ⇒ Object
Returns the value of attribute group_public_ids.
18 19 20 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 18 def group_public_ids @group_public_ids end |
#provider_public_ids ⇒ Object
Returns the value of attribute provider_public_ids.
20 21 22 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 20 def provider_public_ids @provider_public_ids end |
#type ⇒ Object
Returns the value of attribute type.
22 23 24 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 22 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 47 def self.attribute_map { :'group_public_ids' => :'group_public_ids', :'provider_public_ids' => :'provider_public_ids', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 66 def self.openapi_types { :'group_public_ids' => :'Array<String>', :'provider_public_ids' => :'Array<String>', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && group_public_ids == o.group_public_ids && provider_public_ids == o.provider_public_ids && type == o.type end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 165 def hash [group_public_ids, provider_public_ids, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 122 123 124 125 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
129 130 131 132 133 134 135 |
# File 'lib/sendmux_management_generated/models/management_create_mailbox_request_send_scope.rb', line 129 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["all", "providers", "group", "unknown_default_open_api"]) return false unless type_validator.valid?(@type) true end |