Class: Sendmux::Management::Generated::ProviderCreateBodyQuotasPerDayAnyOf

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProviderCreateBodyQuotasPerDayAnyOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::ProviderCreateBodyQuotasPerDayAnyOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::ProviderCreateBodyQuotasPerDayAnyOf`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'max')
    self.max = attributes[:'max']
  else
    self.max = nil
  end

  if attributes.key?(:'min')
    self.min = attributes[:'min']
  else
    self.min = nil
  end
end

Instance Attribute Details

#maxObject

Returns the value of attribute max.



18
19
20
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 18

def max
  @max
end

#minObject

Returns the value of attribute min.



20
21
22
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 20

def min
  @min
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



31
32
33
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 31

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



36
37
38
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 36

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 23

def self.attribute_map
  {
    :'max' => :'max',
    :'min' => :'min'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



55
56
57
58
59
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 55

def self.openapi_all_of
  [
  :'ProviderQuotaRange'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



49
50
51
52
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 49

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



41
42
43
44
45
46
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 41

def self.openapi_types
  {
    :'max' => :'Integer',
    :'min' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      max == o.max &&
      min == o.min
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 170

def hash
  [max, min].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 92

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @max.nil?
    invalid_properties.push('invalid value for "max", max cannot be nil.')
  end

  if @max <= 0
    invalid_properties.push('invalid value for "max", must be greater than 0.')
  end

  if @min.nil?
    invalid_properties.push('invalid value for "min", min cannot be nil.')
  end

  if @min <= 0
    invalid_properties.push('invalid value for "min", must be greater than 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



116
117
118
119
120
121
122
123
# File 'lib/sendmux_management_generated/models/provider_create_body_quotas_per_day_any_of.rb', line 116

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @max.nil?
  return false if @max <= 0
  return false if @min.nil?
  return false if @min <= 0
  true
end