Class: Sendmux::Management::Generated::ProviderQuotas
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Management::Generated::ProviderQuotas
- Defined in:
- lib/sendmux_management_generated/models/provider_quotas.rb
Instance Attribute Summary collapse
-
#per_day ⇒ Object
Returns the value of attribute per_day.
-
#per_hour ⇒ Object
Returns the value of attribute per_hour.
-
#per_minute ⇒ Object
Returns the value of attribute per_minute.
-
#per_second ⇒ Object
Returns the value of attribute per_second.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProviderQuotas
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProviderQuotas
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::ProviderQuotas` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::ProviderQuotas`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'per_day') self.per_day = attributes[:'per_day'] else self.per_day = nil end if attributes.key?(:'per_hour') self.per_hour = attributes[:'per_hour'] else self.per_hour = nil end if attributes.key?(:'per_minute') self.per_minute = attributes[:'per_minute'] else self.per_minute = nil end if attributes.key?(:'per_second') self.per_second = attributes[:'per_second'] else self.per_second = nil end end |
Instance Attribute Details
#per_day ⇒ Object
Returns the value of attribute per_day.
18 19 20 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 18 def per_day @per_day end |
#per_hour ⇒ Object
Returns the value of attribute per_hour.
20 21 22 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 20 def per_hour @per_hour end |
#per_minute ⇒ Object
Returns the value of attribute per_minute.
22 23 24 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 22 def per_minute @per_minute end |
#per_second ⇒ Object
Returns the value of attribute per_second.
24 25 26 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 24 def per_second @per_second end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 27 def self.attribute_map { :'per_day' => :'per_day', :'per_hour' => :'per_hour', :'per_minute' => :'per_minute', :'per_second' => :'per_second' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 148 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 61 62 63 64 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 57 def self.openapi_nullable Set.new([ :'per_day', :'per_hour', :'per_minute', :'per_second' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 47 def self.openapi_types { :'per_day' => :'ProviderQuotaRange', :'per_hour' => :'ProviderQuotaRange', :'per_minute' => :'ProviderQuotaRange', :'per_second' => :'ProviderQuotaRange' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 124 def ==(o) return true if self.equal?(o) self.class == o.class && per_day == o.per_day && per_hour == o.per_hour && per_minute == o.per_minute && per_second == o.per_second end |
#eql?(o) ⇒ Boolean
135 136 137 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 135 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
141 142 143 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 141 def hash [per_day, per_hour, per_minute, per_second].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 109 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 |
# File 'lib/sendmux_management_generated/models/provider_quotas.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |