Class: Sendmux::Management::Generated::SharedAmazonSesLimit

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SharedAmazonSesLimit

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::SharedAmazonSesLimit` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::SharedAmazonSesLimit`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'can_request_increase')
    self.can_request_increase = attributes[:'can_request_increase']
  else
    self.can_request_increase = nil
  end

  if attributes.key?(:'daily_limit')
    self.daily_limit = attributes[:'daily_limit']
  else
    self.daily_limit = nil
  end

  if attributes.key?(:'is_near_limit')
    self.is_near_limit = attributes[:'is_near_limit']
  else
    self.is_near_limit = nil
  end

  if attributes.key?(:'pending_request_id')
    self.pending_request_id = attributes[:'pending_request_id']
  else
    self.pending_request_id = nil
  end

  if attributes.key?(:'provider_id')
    self.provider_id = attributes[:'provider_id']
  else
    self.provider_id = nil
  end

  if attributes.key?(:'sent_today')
    self.sent_today = attributes[:'sent_today']
  else
    self.sent_today = nil
  end

  if attributes.key?(:'threshold_usage')
    self.threshold_usage = attributes[:'threshold_usage']
  else
    self.threshold_usage = nil
  end

  if attributes.key?(:'usage_ratio')
    self.usage_ratio = attributes[:'usage_ratio']
  else
    self.usage_ratio = nil
  end
end

Instance Attribute Details

#can_request_increaseObject

Returns the value of attribute can_request_increase.



18
19
20
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 18

def can_request_increase
  @can_request_increase
end

#daily_limitObject

Returns the value of attribute daily_limit.



20
21
22
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 20

def daily_limit
  @daily_limit
end

#is_near_limitObject

Returns the value of attribute is_near_limit.



22
23
24
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 22

def is_near_limit
  @is_near_limit
end

#pending_request_idObject

Returns the value of attribute pending_request_id.



24
25
26
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 24

def pending_request_id
  @pending_request_id
end

#provider_idObject

Returns the value of attribute provider_id.



26
27
28
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 26

def provider_id
  @provider_id
end

#sent_todayObject

Returns the value of attribute sent_today.



28
29
30
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 28

def sent_today
  @sent_today
end

#threshold_usageObject

Returns the value of attribute threshold_usage.



30
31
32
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 30

def threshold_usage
  @threshold_usage
end

#usage_ratioObject

Returns the value of attribute usage_ratio.



32
33
34
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 32

def usage_ratio
  @usage_ratio
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 35

def self.attribute_map
  {
    :'can_request_increase' => :'can_request_increase',
    :'daily_limit' => :'daily_limit',
    :'is_near_limit' => :'is_near_limit',
    :'pending_request_id' => :'pending_request_id',
    :'provider_id' => :'provider_id',
    :'sent_today' => :'sent_today',
    :'threshold_usage' => :'threshold_usage',
    :'usage_ratio' => :'usage_ratio'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 277

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
78
79
80
81
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 73

def self.openapi_nullable
  Set.new([
    :'daily_limit',
    :'pending_request_id',
    :'provider_id',
    :'threshold_usage',
    :'usage_ratio'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 59

def self.openapi_types
  {
    :'can_request_increase' => :'Boolean',
    :'daily_limit' => :'Integer',
    :'is_near_limit' => :'Boolean',
    :'pending_request_id' => :'String',
    :'provider_id' => :'String',
    :'sent_today' => :'Integer',
    :'threshold_usage' => :'Integer',
    :'usage_ratio' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      can_request_increase == o.can_request_increase &&
      daily_limit == o.daily_limit &&
      is_near_limit == o.is_near_limit &&
      pending_request_id == o.pending_request_id &&
      provider_id == o.provider_id &&
      sent_today == o.sent_today &&
      threshold_usage == o.threshold_usage &&
      usage_ratio == o.usage_ratio
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


264
265
266
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 264

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



270
271
272
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 270

def hash
  [can_request_increase, daily_limit, is_near_limit, pending_request_id, provider_id, sent_today, threshold_usage, usage_ratio].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @can_request_increase.nil?
    invalid_properties.push('invalid value for "can_request_increase", can_request_increase cannot be nil.')
  end

  if @daily_limit < 0
    invalid_properties.push('invalid value for "daily_limit", must be greater than or equal to 0.')
  end

  if @is_near_limit.nil?
    invalid_properties.push('invalid value for "is_near_limit", is_near_limit cannot be nil.')
  end

  if @sent_today.nil?
    invalid_properties.push('invalid value for "sent_today", sent_today cannot be nil.')
  end

  if @sent_today < 0
    invalid_properties.push('invalid value for "sent_today", must be greater than or equal to 0.')
  end

  if @threshold_usage < 0
    invalid_properties.push('invalid value for "threshold_usage", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 299

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
188
189
190
191
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @can_request_increase.nil?
  return false if @daily_limit < 0
  return false if @is_near_limit.nil?
  return false if @sent_today.nil?
  return false if @sent_today < 0
  return false if @threshold_usage < 0
  true
end