Class: Sendmux::Management::Generated::SharedAmazonSesLimitRequestCreateRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SharedAmazonSesLimitRequestCreateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::SharedAmazonSesLimitRequestCreateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::SharedAmazonSesLimitRequestCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'approved_daily_limit')
    self.approved_daily_limit = attributes[:'approved_daily_limit']
  else
    self.approved_daily_limit = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'current_daily_limit')
    self.current_daily_limit = attributes[:'current_daily_limit']
  else
    self.current_daily_limit = nil
  end

  if attributes.key?(:'current_daily_sent')
    self.current_daily_sent = attributes[:'current_daily_sent']
  else
    self.current_daily_sent = nil
  end

  if attributes.key?(:'decided_at')
    self.decided_at = attributes[:'decided_at']
  else
    self.decided_at = nil
  end

  if attributes.key?(:'decision_note')
    self.decision_note = attributes[:'decision_note']
  else
    self.decision_note = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end
end

Instance Attribute Details

#approved_daily_limitObject

Returns the value of attribute approved_daily_limit.



18
19
20
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 18

def approved_daily_limit
  @approved_daily_limit
end

#created_atObject

Returns the value of attribute created_at.



20
21
22
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 20

def created_at
  @created_at
end

#current_daily_limitObject

Returns the value of attribute current_daily_limit.



22
23
24
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 22

def current_daily_limit
  @current_daily_limit
end

#current_daily_sentObject

Returns the value of attribute current_daily_sent.



24
25
26
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 24

def current_daily_sent
  @current_daily_sent
end

#decided_atObject

Returns the value of attribute decided_at.



26
27
28
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 26

def decided_at
  @decided_at
end

#decision_noteObject

Returns the value of attribute decision_note.



28
29
30
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 28

def decision_note
  @decision_note
end

#idObject

Returns the value of attribute id.



30
31
32
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 30

def id
  @id
end

#statusObject

Returns the value of attribute status.



32
33
34
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 32

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 57

def self.attribute_map
  {
    :'approved_daily_limit' => :'approved_daily_limit',
    :'created_at' => :'created_at',
    :'current_daily_limit' => :'current_daily_limit',
    :'current_daily_sent' => :'current_daily_sent',
    :'decided_at' => :'decided_at',
    :'decision_note' => :'decision_note',
    :'id' => :'id',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 330

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



104
105
106
107
108
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 104

def self.openapi_all_of
  [
  :'SharedAmazonSesLimitRequest'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
99
100
101
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 95

def self.openapi_nullable
  Set.new([
    :'approved_daily_limit',
    :'decided_at',
    :'decision_note',
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 81

def self.openapi_types
  {
    :'approved_daily_limit' => :'Integer',
    :'created_at' => :'String',
    :'current_daily_limit' => :'Integer',
    :'current_daily_sent' => :'Integer',
    :'decided_at' => :'String',
    :'decision_note' => :'String',
    :'id' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 302

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      approved_daily_limit == o.approved_daily_limit &&
      created_at == o.created_at &&
      current_daily_limit == o.current_daily_limit &&
      current_daily_sent == o.current_daily_sent &&
      decided_at == o.decided_at &&
      decision_note == o.decision_note &&
      id == o.id &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


317
318
319
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 317

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



323
324
325
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 323

def hash
  [approved_daily_limit, created_at, current_daily_limit, current_daily_sent, decided_at, decision_note, id, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @approved_daily_limit <= 0
    invalid_properties.push('invalid value for "approved_daily_limit", must be greater than 0.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @current_daily_limit.nil?
    invalid_properties.push('invalid value for "current_daily_limit", current_daily_limit cannot be nil.')
  end

  if @current_daily_limit < 0
    invalid_properties.push('invalid value for "current_daily_limit", must be greater than or equal to 0.')
  end

  if @current_daily_sent.nil?
    invalid_properties.push('invalid value for "current_daily_sent", current_daily_sent cannot be nil.')
  end

  if @current_daily_sent < 0
    invalid_properties.push('invalid value for "current_daily_sent", must be greater than or equal to 0.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 352

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/sendmux_management_generated/models/shared_amazon_ses_limit_request_create_request.rb', line 217

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @approved_daily_limit <= 0
  return false if @created_at.nil?
  return false if @current_daily_limit.nil?
  return false if @current_daily_limit < 0
  return false if @current_daily_sent.nil?
  return false if @current_daily_sent < 0
  return false if @id.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["pending", "approved", "denied", "unknown_default_open_api"])
  return false unless status_validator.valid?(@status)
  true
end