Class: Sendmux::Management::Generated::UpdateMailboxBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Management::Generated::UpdateMailboxBody
- Defined in:
- lib/sendmux_management_generated/models/update_mailbox_body.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#quota_bytes ⇒ Object
Storage quota in bytes.
-
#send_scope ⇒ Object
Returns the value of attribute send_scope.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateMailboxBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateMailboxBody
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::UpdateMailboxBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::UpdateMailboxBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'quota_bytes') self.quota_bytes = attributes[:'quota_bytes'] end if attributes.key?(:'send_scope') self.send_scope = attributes[:'send_scope'] end end |
Instance Attribute Details
#display_name ⇒ Object
Returns the value of attribute display_name.
18 19 20 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 18 def display_name @display_name end |
#quota_bytes ⇒ Object
Storage quota in bytes. Allowed values: 1073741824 (1 GB), 5368709120 (5 GB), 53687091200 (50 GB).
21 22 23 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 21 def quota_bytes @quota_bytes end |
#send_scope ⇒ Object
Returns the value of attribute send_scope.
23 24 25 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 23 def send_scope @send_scope end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 26 def self.attribute_map { :'display_name' => :'display_name', :'quota_bytes' => :'quota_bytes', :'send_scope' => :'send_scope' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
54 55 56 57 58 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 54 def self.openapi_nullable Set.new([ :'display_name', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 45 def self.openapi_types { :'display_name' => :'String', :'quota_bytes' => :'Integer', :'send_scope' => :'ManagementCreateMailboxRequestSendScope' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && display_name == o.display_name && quota_bytes == o.quota_bytes && send_scope == o.send_scope end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 165 def hash [display_name, quota_bytes, send_scope].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 91 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@display_name.nil? && @display_name.to_s.length > 254 invalid_properties.push('invalid value for "display_name", the character length must be smaller than or equal to 254.') end if !@display_name.nil? && @display_name.to_s.length < 1 invalid_properties.push('invalid value for "display_name", the character length must be greater than or equal to 1.') end if !@quota_bytes.nil? && @quota_bytes < 1 invalid_properties.push('invalid value for "quota_bytes", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
111 112 113 114 115 116 117 |
# File 'lib/sendmux_management_generated/models/update_mailbox_body.rb', line 111 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@display_name.nil? && @display_name.to_s.length > 254 return false if !@display_name.nil? && @display_name.to_s.length < 1 return false if !@quota_bytes.nil? && @quota_bytes < 1 true end |