Class: Sendmux::Management::Generated::WebhookDeliveryPayload

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/webhook_delivery_payload.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookDeliveryPayload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::WebhookDeliveryPayload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::WebhookDeliveryPayload`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'delivery_attempt')
    self.delivery_attempt = attributes[:'delivery_attempt']
  else
    self.delivery_attempt = nil
  end

  if attributes.key?(:'event_id')
    self.event_id = attributes[:'event_id']
  else
    self.event_id = nil
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  else
    self.event_type = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  else
    self.expires_at = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  else
    self.payload = nil
  end
end

Instance Attribute Details

#created_atObject

ISO 8601 attempt timestamp



19
20
21
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 19

def created_at
  @created_at
end

#delivery_attemptObject

1-based retry attempt number.



22
23
24
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 22

def delivery_attempt
  @delivery_attempt
end

#event_idObject

Webhook event ID



25
26
27
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 25

def event_id
  @event_id
end

#event_typeObject

Event types a webhook may subscribe to. ‘sendmux.test` is accepted so you can verify end-to-end delivery via POST /webhooks/#id/test.



28
29
30
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 28

def event_type
  @event_type
end

#expires_atObject

Timestamp when this retained payload expires.



31
32
33
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 31

def expires_at
  @expires_at
end

#idObject

Delivery-attempt public ID



34
35
36
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 34

def id
  @id
end

#payloadObject

Returns the value of attribute payload.



36
37
38
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 36

def payload
  @payload
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 61

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'delivery_attempt' => :'delivery_attempt',
    :'event_id' => :'event_id',
    :'event_type' => :'event_type',
    :'expires_at' => :'expires_at',
    :'id' => :'id',
    :'payload' => :'payload'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 321

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 84

def self.openapi_types
  {
    :'created_at' => :'String',
    :'delivery_attempt' => :'Integer',
    :'event_id' => :'String',
    :'event_type' => :'String',
    :'expires_at' => :'String',
    :'id' => :'String',
    :'payload' => :'WebhookEventPayload'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



294
295
296
297
298
299
300
301
302
303
304
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 294

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      delivery_attempt == o.delivery_attempt &&
      event_id == o.event_id &&
      event_type == o.event_type &&
      expires_at == o.expires_at &&
      id == o.id &&
      payload == o.payload
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


308
309
310
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 308

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



314
315
316
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 314

def hash
  [created_at, delivery_attempt, event_id, event_type, expires_at, id, payload].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 163

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @delivery_attempt.nil?
    invalid_properties.push('invalid value for "delivery_attempt", delivery_attempt cannot be nil.')
  end

  if @delivery_attempt <= 0
    invalid_properties.push('invalid value for "delivery_attempt", must be greater than 0.')
  end

  if @event_id.nil?
    invalid_properties.push('invalid value for "event_id", event_id cannot be nil.')
  end

  if @event_type.nil?
    invalid_properties.push('invalid value for "event_type", event_type cannot be nil.')
  end

  if @expires_at.nil?
    invalid_properties.push('invalid value for "expires_at", expires_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @payload.nil?
    invalid_properties.push('invalid value for "payload", payload cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/sendmux_management_generated/models/webhook_delivery_payload.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @delivery_attempt.nil?
  return false if @delivery_attempt <= 0
  return false if @event_id.nil?
  return false if @event_type.nil?
  event_type_validator = EnumAttributeValidator.new('String', ["message.delivered", "message.bounced", "message.complained", "message.rejected", "message.delivery_delayed", "message.received", "message.received.spam", "sendmux.test", "unknown_default_open_api"])
  return false unless event_type_validator.valid?(@event_type)
  return false if @expires_at.nil?
  return false if @id.nil?
  return false if @payload.nil?
  true
end