Class: Sendmux::Management::Generated::WebhookSubscriptionWithSecret

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookSubscriptionWithSecret

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::WebhookSubscriptionWithSecret` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::WebhookSubscriptionWithSecret`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'event_types')
    if (value = attributes[:'event_types']).is_a?(Array)
      self.event_types = value
    end
  else
    self.event_types = nil
  end

  if attributes.key?(:'failing')
    self.failing = attributes[:'failing']
  else
    self.failing = nil
  end

  if attributes.key?(:'filters')
    self.filters = attributes[:'filters']
  else
    self.filters = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'secret')
    self.secret = attributes[:'secret']
  else
    self.secret = nil
  end
end

Instance Attribute Details

#created_atObject

ISO 8601 creation timestamp



19
20
21
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 19

def created_at
  @created_at
end

#enabledObject

When false, no events are delivered to this subscription.



22
23
24
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 22

def enabled
  @enabled
end

#event_typesObject

Event types this subscription receives.



25
26
27
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 25

def event_types
  @event_types
end

#failingObject

True when the 24-hour retry window has been exhausted for this subscription. Reset by updating the subscription (e.g. fixing the URL) and re-enabling.



28
29
30
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 28

def failing
  @failing
end

#filtersObject

Returns the value of attribute filters.



30
31
32
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 30

def filters
  @filters
end

#idObject

Webhook public ID



33
34
35
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 33

def id
  @id
end

#nameObject

Optional human-friendly label used in dashboard list/detail pages. May be ‘null` for subscriptions created without a name.



36
37
38
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 36

def name
  @name
end

#secretObject

Signing secret used to verify the HMAC-SHA256 signature on every event POST. This is the ONLY response containing the raw secret — store it securely; it cannot be retrieved later. Use POST /webhooks/#id/rotate-secret to issue a new one.



45
46
47
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 45

def secret
  @secret
end

#updated_atObject

ISO 8601 last-modified timestamp



39
40
41
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 39

def updated_at
  @updated_at
end

#urlObject

HTTPS endpoint that receives signed event POSTs.



42
43
44
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 42

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 70

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'enabled' => :'enabled',
    :'event_types' => :'event_types',
    :'failing' => :'failing',
    :'filters' => :'filters',
    :'id' => :'id',
    :'name' => :'name',
    :'updated_at' => :'updated_at',
    :'url' => :'url',
    :'secret' => :'secret'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 376

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



119
120
121
122
123
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 119

def self.openapi_all_of
  [
  :'WebhookSubscription'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 112

def self.openapi_nullable
  Set.new([
    :'name',
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 96

def self.openapi_types
  {
    :'created_at' => :'String',
    :'enabled' => :'Boolean',
    :'event_types' => :'Array<String>',
    :'failing' => :'Boolean',
    :'filters' => :'WebhookFilters',
    :'id' => :'String',
    :'name' => :'String',
    :'updated_at' => :'String',
    :'url' => :'String',
    :'secret' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 346

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      enabled == o.enabled &&
      event_types == o.event_types &&
      failing == o.failing &&
      filters == o.filters &&
      id == o.id &&
      name == o.name &&
      updated_at == o.updated_at &&
      url == o.url &&
      secret == o.secret
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


363
364
365
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 363

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



369
370
371
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 369

def hash
  [created_at, enabled, event_types, failing, filters, id, name, updated_at, url, secret].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 206

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @event_types.nil?
    invalid_properties.push('invalid value for "event_types", event_types cannot be nil.')
  end

  if @failing.nil?
    invalid_properties.push('invalid value for "failing", failing cannot be nil.')
  end

  if @filters.nil?
    invalid_properties.push('invalid value for "filters", filters cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @secret.nil?
    invalid_properties.push('invalid value for "secret", secret cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 398

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/sendmux_management_generated/models/webhook_subscription_with_secret.rb', line 250

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @enabled.nil?
  return false if @event_types.nil?
  return false if @failing.nil?
  return false if @filters.nil?
  return false if @id.nil?
  return false if @updated_at.nil?
  return false if @url.nil?
  return false if @secret.nil?
  true
end