Class: Sendmux::Management::Generated::DeliveryLogItem

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/delivery_log_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeliveryLogItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::DeliveryLogItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::DeliveryLogItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attempts')
    self.attempts = attributes[:'attempts']
  else
    self.attempts = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'from_email')
    self.from_email = attributes[:'from_email']
  else
    self.from_email = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'message_id')
    self.message_id = attributes[:'message_id']
  else
    self.message_id = nil
  end

  if attributes.key?(:'provider_id')
    self.provider_id = attributes[:'provider_id']
  else
    self.provider_id = nil
  end

  if attributes.key?(:'provider_name')
    self.provider_name = attributes[:'provider_name']
  else
    self.provider_name = nil
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  else
    self.sent_at = nil
  end

  if attributes.key?(:'sent_from_email')
    self.sent_from_email = attributes[:'sent_from_email']
  else
    self.sent_from_email = nil
  end

  if attributes.key?(:'size_bytes')
    self.size_bytes = attributes[:'size_bytes']
  else
    self.size_bytes = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'status_reason')
    self.status_reason = attributes[:'status_reason']
  else
    self.status_reason = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'to_email')
    self.to_email = attributes[:'to_email']
  else
    self.to_email = nil
  end
end

Instance Attribute Details

#attemptsObject

Returns the value of attribute attempts.



18
19
20
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 18

def attempts
  @attempts
end

#created_atObject

ISO 8601 creation timestamp



21
22
23
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 21

def created_at
  @created_at
end

#from_emailObject

Returns the value of attribute from_email.



23
24
25
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 23

def from_email
  @from_email
end

#idObject

Log public ID



26
27
28
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 26

def id
  @id
end

#message_idObject

Email Message-ID header



29
30
31
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 29

def message_id
  @message_id
end

#provider_idObject

Provider public ID



32
33
34
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 32

def provider_id
  @provider_id
end

#provider_nameObject

Provider display name



35
36
37
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 35

def provider_name
  @provider_name
end

#sent_atObject

ISO 8601 timestamp when email was sent



38
39
40
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 38

def sent_at
  @sent_at
end

#sent_from_emailObject

The actual from address used for delivery after transformation. NULL if no transformation occurred or for older log entries.



41
42
43
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 41

def sent_from_email
  @sent_from_email
end

#size_bytesObject

Returns the value of attribute size_bytes.



43
44
45
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 43

def size_bytes
  @size_bytes
end

#statusObject

Returns the value of attribute status.



45
46
47
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 45

def status
  @status
end

#status_reasonObject

Returns the value of attribute status_reason.



47
48
49
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 47

def status_reason
  @status_reason
end

#subjectObject

Returns the value of attribute subject.



49
50
51
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 49

def subject
  @subject
end

#to_emailObject

Returns the value of attribute to_email.



51
52
53
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 51

def to_email
  @to_email
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



96
97
98
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 96

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



101
102
103
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 101

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 76

def self.attribute_map
  {
    :'attempts' => :'attempts',
    :'created_at' => :'created_at',
    :'from_email' => :'from_email',
    :'id' => :'id',
    :'message_id' => :'message_id',
    :'provider_id' => :'provider_id',
    :'provider_name' => :'provider_name',
    :'sent_at' => :'sent_at',
    :'sent_from_email' => :'sent_from_email',
    :'size_bytes' => :'size_bytes',
    :'status' => :'status',
    :'status_reason' => :'status_reason',
    :'subject' => :'subject',
    :'to_email' => :'to_email'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 355

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 126

def self.openapi_nullable
  Set.new([
    :'from_email',
    :'message_id',
    :'provider_id',
    :'provider_name',
    :'sent_at',
    :'sent_from_email',
    :'size_bytes',
    :'status_reason',
    :'subject',
    :'to_email'
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 106

def self.openapi_types
  {
    :'attempts' => :'Float',
    :'created_at' => :'String',
    :'from_email' => :'String',
    :'id' => :'String',
    :'message_id' => :'String',
    :'provider_id' => :'String',
    :'provider_name' => :'String',
    :'sent_at' => :'String',
    :'sent_from_email' => :'String',
    :'size_bytes' => :'Float',
    :'status' => :'String',
    :'status_reason' => :'String',
    :'subject' => :'String',
    :'to_email' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 321

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attempts == o.attempts &&
      created_at == o.created_at &&
      from_email == o.from_email &&
      id == o.id &&
      message_id == o.message_id &&
      provider_id == o.provider_id &&
      provider_name == o.provider_name &&
      sent_at == o.sent_at &&
      sent_from_email == o.sent_from_email &&
      size_bytes == o.size_bytes &&
      status == o.status &&
      status_reason == o.status_reason &&
      subject == o.subject &&
      to_email == o.to_email
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


342
343
344
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 342

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



348
349
350
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 348

def hash
  [attempts, created_at, from_email, id, message_id, provider_id, provider_name, sent_at, sent_from_email, size_bytes, status, status_reason, subject, to_email].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 244

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @attempts.nil?
    invalid_properties.push('invalid value for "attempts", attempts cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 377

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



268
269
270
271
272
273
274
275
276
277
# File 'lib/sendmux_management_generated/models/delivery_log_item.rb', line 268

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @attempts.nil?
  return false if @created_at.nil?
  return false if @id.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["pending", "sent", "failed", "rejected", "unknown_default_open_api"])
  return false unless status_validator.valid?(@status)
  true
end