Class: Sendmux::Management::Generated::MailboxAppPasswordResultCredential
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Management::Generated::MailboxAppPasswordResultCredential
- Defined in:
- lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb
Instance Attribute Summary collapse
-
#imap_port ⇒ Object
IMAP retrieval port.
-
#key_prefix ⇒ Object
Returns the value of attribute key_prefix.
-
#key_suffix ⇒ Object
Returns the value of attribute key_suffix.
-
#public_id ⇒ Object
Credential public ID.
-
#secret ⇒ Object
Mailbox credential — shown exactly once.
-
#server ⇒ Object
Mailbox server name.
-
#smtp_port ⇒ Object
SMTP submission port.
-
#username ⇒ Object
Mailbox email address used as the login.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MailboxAppPasswordResultCredential
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MailboxAppPasswordResultCredential
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::MailboxAppPasswordResultCredential` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::MailboxAppPasswordResultCredential`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'imap_port') self.imap_port = attributes[:'imap_port'] else self.imap_port = nil end if attributes.key?(:'key_prefix') self.key_prefix = attributes[:'key_prefix'] else self.key_prefix = nil end if attributes.key?(:'key_suffix') self.key_suffix = attributes[:'key_suffix'] else self.key_suffix = nil end if attributes.key?(:'public_id') self.public_id = attributes[:'public_id'] else self.public_id = nil end if attributes.key?(:'secret') self.secret = attributes[:'secret'] else self.secret = nil end if attributes.key?(:'server') self.server = attributes[:'server'] else self.server = nil end if attributes.key?(:'smtp_port') self.smtp_port = attributes[:'smtp_port'] else self.smtp_port = nil end if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end end |
Instance Attribute Details
#imap_port ⇒ Object
IMAP retrieval port
19 20 21 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 19 def imap_port @imap_port end |
#key_prefix ⇒ Object
Returns the value of attribute key_prefix.
21 22 23 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 21 def key_prefix @key_prefix end |
#key_suffix ⇒ Object
Returns the value of attribute key_suffix.
23 24 25 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 23 def key_suffix @key_suffix end |
#public_id ⇒ Object
Credential public ID
26 27 28 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 26 def public_id @public_id end |
#secret ⇒ Object
Mailbox credential — shown exactly once. Use as a Bearer token on the HTTP API and as the password for IMAP retrieval and SMTP submission.
29 30 31 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 29 def secret @secret end |
#server ⇒ Object
Mailbox server name
32 33 34 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 32 def server @server end |
#smtp_port ⇒ Object
SMTP submission port
35 36 37 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 35 def smtp_port @smtp_port end |
#username ⇒ Object
Mailbox email address used as the login
38 39 40 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 38 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 41 def self.attribute_map { :'imap_port' => :'imap_port', :'key_prefix' => :'key_prefix', :'key_suffix' => :'key_suffix', :'public_id' => :'public_id', :'secret' => :'secret', :'server' => :'server', :'smtp_port' => :'smtp_port', :'username' => :'username' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 321 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
85 86 87 88 89 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 85 def self.openapi_all_of [ :'MailboxCredential' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 65 def self.openapi_types { :'imap_port' => :'Integer', :'key_prefix' => :'String', :'key_suffix' => :'String', :'public_id' => :'String', :'secret' => :'String', :'server' => :'String', :'smtp_port' => :'Integer', :'username' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 293 def ==(o) return true if self.equal?(o) self.class == o.class && imap_port == o.imap_port && key_prefix == o.key_prefix && key_suffix == o.key_suffix && public_id == o.public_id && secret == o.secret && server == o.server && smtp_port == o.smtp_port && username == o.username end |
#eql?(o) ⇒ Boolean
308 309 310 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 308 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
314 315 316 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 314 def hash [imap_port, key_prefix, key_suffix, public_id, secret, server, smtp_port, username].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 158 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @imap_port.nil? invalid_properties.push('invalid value for "imap_port", imap_port cannot be nil.') end if @key_prefix.nil? invalid_properties.push('invalid value for "key_prefix", key_prefix cannot be nil.') end if @key_suffix.nil? invalid_properties.push('invalid value for "key_suffix", key_suffix cannot be nil.') end if @public_id.nil? invalid_properties.push('invalid value for "public_id", public_id cannot be nil.') end if @secret.nil? invalid_properties.push('invalid value for "secret", secret cannot be nil.') end if @server.nil? invalid_properties.push('invalid value for "server", server cannot be nil.') end if @smtp_port.nil? invalid_properties.push('invalid value for "smtp_port", smtp_port cannot be nil.') end if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 343 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/sendmux_management_generated/models/mailbox_app_password_result_credential.rb', line 198 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @imap_port.nil? return false if @key_prefix.nil? return false if @key_suffix.nil? return false if @public_id.nil? return false if @secret.nil? return false if @server.nil? return false if @smtp_port.nil? return false if @username.nil? true end |