Class: Sendmux::Management::Generated::MailboxDomain

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/mailbox_domain.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxDomain

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::MailboxDomain` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::MailboxDomain`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'dns_records')
    self.dns_records = attributes[:'dns_records']
  else
    self.dns_records = nil
  end

  if attributes.key?(:'domain')
    self.domain = attributes[:'domain']
  else
    self.domain = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'mailbox_count')
    self.mailbox_count = attributes[:'mailbox_count']
  else
    self.mailbox_count = nil
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = nil
  end

  if attributes.key?(:'ses_dkim_status')
    self.ses_dkim_status = attributes[:'ses_dkim_status']
  else
    self.ses_dkim_status = nil
  end

  if attributes.key?(:'ses_mail_from_status')
    self.ses_mail_from_status = attributes[:'ses_mail_from_status']
  else
    self.ses_mail_from_status = nil
  end

  if attributes.key?(:'verification_status')
    self.verification_status = attributes[:'verification_status']
  else
    self.verification_status = nil
  end

  if attributes.key?(:'verified_at')
    self.verified_at = attributes[:'verified_at']
  else
    self.verified_at = nil
  end
end

Instance Attribute Details

#created_atObject

ISO 8601 creation timestamp



19
20
21
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 19

def created_at
  @created_at
end

#dns_recordsObject

Returns the value of attribute dns_records.



21
22
23
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 21

def dns_records
  @dns_records
end

#domainObject

Fully qualified domain name



24
25
26
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 24

def domain
  @domain
end

#idObject

Public ID



27
28
29
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 27

def id
  @id
end

#mailbox_countObject

Active mailboxes currently using this domain



30
31
32
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 30

def mailbox_count
  @mailbox_count
end

#modeObject

send_only verifies outbound DNS only. send_receive also verifies MX records and can host mailboxes.



33
34
35
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 33

def mode
  @mode
end

#ses_dkim_statusObject

Amazon SES DKIM status (pending/success/failed/temporary_failure/not_started)



36
37
38
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 36

def ses_dkim_status
  @ses_dkim_status
end

#ses_mail_from_statusObject

Amazon SES MAIL FROM status (pending/success/failed/temporary_failure/not_started)



39
40
41
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 39

def ses_mail_from_status
  @ses_mail_from_status
end

#verification_statusObject

Current verification state



42
43
44
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 42

def verification_status
  @verification_status
end

#verified_atObject

ISO 8601 timestamp of last successful verification



45
46
47
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 45

def verified_at
  @verified_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 70

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'dns_records' => :'dns_records',
    :'domain' => :'domain',
    :'id' => :'id',
    :'mailbox_count' => :'mailbox_count',
    :'mode' => :'mode',
    :'ses_dkim_status' => :'ses_dkim_status',
    :'ses_mail_from_status' => :'ses_mail_from_status',
    :'verification_status' => :'verification_status',
    :'verified_at' => :'verified_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 362

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
117
118
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 112

def self.openapi_nullable
  Set.new([
    :'ses_dkim_status',
    :'ses_mail_from_status',
    :'verified_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 96

def self.openapi_types
  {
    :'created_at' => :'String',
    :'dns_records' => :'MailboxDomainDnsRecords',
    :'domain' => :'String',
    :'id' => :'String',
    :'mailbox_count' => :'Integer',
    :'mode' => :'String',
    :'ses_dkim_status' => :'String',
    :'ses_mail_from_status' => :'String',
    :'verification_status' => :'String',
    :'verified_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 332

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      dns_records == o.dns_records &&
      domain == o.domain &&
      id == o.id &&
      mailbox_count == o.mailbox_count &&
      mode == o.mode &&
      ses_dkim_status == o.ses_dkim_status &&
      ses_mail_from_status == o.ses_mail_from_status &&
      verification_status == o.verification_status &&
      verified_at == o.verified_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


349
350
351
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 349

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



355
356
357
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 355

def hash
  [created_at, dns_records, domain, id, mailbox_count, mode, ses_dkim_status, ses_mail_from_status, verification_status, verified_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 199

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @dns_records.nil?
    invalid_properties.push('invalid value for "dns_records", dns_records cannot be nil.')
  end

  if @domain.nil?
    invalid_properties.push('invalid value for "domain", domain cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @mailbox_count.nil?
    invalid_properties.push('invalid value for "mailbox_count", mailbox_count cannot be nil.')
  end

  if @mailbox_count < 0
    invalid_properties.push('invalid value for "mailbox_count", must be greater than or equal to 0.')
  end

  if @mode.nil?
    invalid_properties.push('invalid value for "mode", mode cannot be nil.')
  end

  if @verification_status.nil?
    invalid_properties.push('invalid value for "verification_status", verification_status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 384

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 239

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @dns_records.nil?
  return false if @domain.nil?
  return false if @id.nil?
  return false if @mailbox_count.nil?
  return false if @mailbox_count < 0
  return false if @mode.nil?
  mode_validator = EnumAttributeValidator.new('String', ["send_only", "send_receive", "unknown_default_open_api"])
  return false unless mode_validator.valid?(@mode)
  return false if @verification_status.nil?
  verification_status_validator = EnumAttributeValidator.new('String', ["pending", "verified", "failed", "unknown_default_open_api"])
  return false unless verification_status_validator.valid?(@verification_status)
  true
end