Class: Sendmux::Management::Generated::MailboxDomain

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/sendmux_management_generated/models/mailbox_domain.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MailboxDomain

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::MailboxDomain` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::MailboxDomain`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'dns_records')
    self.dns_records = attributes[:'dns_records']
  else
    self.dns_records = nil
  end

  if attributes.key?(:'domain')
    self.domain = attributes[:'domain']
  else
    self.domain = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'mailbox_count')
    self.mailbox_count = attributes[:'mailbox_count']
  else
    self.mailbox_count = nil
  end

  if attributes.key?(:'ses_dkim_status')
    self.ses_dkim_status = attributes[:'ses_dkim_status']
  else
    self.ses_dkim_status = nil
  end

  if attributes.key?(:'verification_status')
    self.verification_status = attributes[:'verification_status']
  else
    self.verification_status = nil
  end

  if attributes.key?(:'verified_at')
    self.verified_at = attributes[:'verified_at']
  else
    self.verified_at = nil
  end
end

Instance Attribute Details

#created_atObject

ISO 8601 creation timestamp



19
20
21
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 19

def created_at
  @created_at
end

#dns_recordsObject

Returns the value of attribute dns_records.



21
22
23
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 21

def dns_records
  @dns_records
end

#domainObject

Fully qualified domain name



24
25
26
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 24

def domain
  @domain
end

#idObject

Public ID



27
28
29
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 27

def id
  @id
end

#mailbox_countObject

Active mailboxes currently using this domain



30
31
32
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 30

def mailbox_count
  @mailbox_count
end

#ses_dkim_statusObject

SES DKIM status (pending/success/failed/temporary_failure/not_started)



33
34
35
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 33

def ses_dkim_status
  @ses_dkim_status
end

#verification_statusObject

Current verification state



36
37
38
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 36

def verification_status
  @verification_status
end

#verified_atObject

ISO 8601 timestamp of last successful verification



39
40
41
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 39

def verified_at
  @verified_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 64

def self.attribute_map
  {
    :'created_at' => :'created_at',
    :'dns_records' => :'dns_records',
    :'domain' => :'domain',
    :'id' => :'id',
    :'mailbox_count' => :'mailbox_count',
    :'ses_dkim_status' => :'ses_dkim_status',
    :'verification_status' => :'verification_status',
    :'verified_at' => :'verified_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 320

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 102

def self.openapi_nullable
  Set.new([
    :'ses_dkim_status',
    :'verified_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 88

def self.openapi_types
  {
    :'created_at' => :'String',
    :'dns_records' => :'MailboxDomainDnsRecords',
    :'domain' => :'String',
    :'id' => :'String',
    :'mailbox_count' => :'Integer',
    :'ses_dkim_status' => :'String',
    :'verification_status' => :'String',
    :'verified_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 292

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      dns_records == o.dns_records &&
      domain == o.domain &&
      id == o.id &&
      mailbox_count == o.mailbox_count &&
      ses_dkim_status == o.ses_dkim_status &&
      verification_status == o.verification_status &&
      verified_at == o.verified_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


307
308
309
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 307

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



313
314
315
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 313

def hash
  [created_at, dns_records, domain, id, mailbox_count, ses_dkim_status, verification_status, verified_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @dns_records.nil?
    invalid_properties.push('invalid value for "dns_records", dns_records cannot be nil.')
  end

  if @domain.nil?
    invalid_properties.push('invalid value for "domain", domain cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @mailbox_count.nil?
    invalid_properties.push('invalid value for "mailbox_count", mailbox_count cannot be nil.')
  end

  if @mailbox_count < 0
    invalid_properties.push('invalid value for "mailbox_count", must be greater than or equal to 0.')
  end

  if @verification_status.nil?
    invalid_properties.push('invalid value for "verification_status", verification_status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 342

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/sendmux_management_generated/models/mailbox_domain.rb', line 212

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @dns_records.nil?
  return false if @domain.nil?
  return false if @id.nil?
  return false if @mailbox_count.nil?
  return false if @mailbox_count < 0
  return false if @verification_status.nil?
  verification_status_validator = EnumAttributeValidator.new('String', ["pending", "verified", "failed", "unknown_default_open_api"])
  return false unless verification_status_validator.valid?(@verification_status)
  true
end