Class: Sendmux::Management::Generated::ProviderUsageItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Management::Generated::ProviderUsageItem
- Defined in:
- lib/sendmux_management_generated/models/provider_usage_item.rb
Instance Attribute Summary collapse
-
#failed_7d ⇒ Object
Returns the value of attribute failed_7d.
-
#pending_7d ⇒ Object
Returns the value of attribute pending_7d.
-
#provider_id ⇒ Object
Returns the value of attribute provider_id.
-
#rejected_7d ⇒ Object
Returns the value of attribute rejected_7d.
-
#sent_7d ⇒ Object
Returns the value of attribute sent_7d.
-
#sent_today ⇒ Object
Returns the value of attribute sent_today.
-
#total_7d ⇒ Object
Returns the value of attribute total_7d.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProviderUsageItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProviderUsageItem
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::ProviderUsageItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::ProviderUsageItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'failed_7d') self.failed_7d = attributes[:'failed_7d'] else self.failed_7d = nil end if attributes.key?(:'pending_7d') self.pending_7d = attributes[:'pending_7d'] else self.pending_7d = nil end if attributes.key?(:'provider_id') self.provider_id = attributes[:'provider_id'] else self.provider_id = nil end if attributes.key?(:'rejected_7d') self.rejected_7d = attributes[:'rejected_7d'] else self.rejected_7d = nil end if attributes.key?(:'sent_7d') self.sent_7d = attributes[:'sent_7d'] else self.sent_7d = nil end if attributes.key?(:'sent_today') self.sent_today = attributes[:'sent_today'] else self.sent_today = nil end if attributes.key?(:'total_7d') self.total_7d = attributes[:'total_7d'] else self.total_7d = nil end end |
Instance Attribute Details
#failed_7d ⇒ Object
Returns the value of attribute failed_7d.
18 19 20 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 18 def failed_7d @failed_7d end |
#pending_7d ⇒ Object
Returns the value of attribute pending_7d.
20 21 22 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 20 def pending_7d @pending_7d end |
#provider_id ⇒ Object
Returns the value of attribute provider_id.
22 23 24 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 22 def provider_id @provider_id end |
#rejected_7d ⇒ Object
Returns the value of attribute rejected_7d.
24 25 26 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 24 def rejected_7d @rejected_7d end |
#sent_7d ⇒ Object
Returns the value of attribute sent_7d.
26 27 28 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 26 def sent_7d @sent_7d end |
#sent_today ⇒ Object
Returns the value of attribute sent_today.
28 29 30 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 28 def sent_today @sent_today end |
#total_7d ⇒ Object
Returns the value of attribute total_7d.
30 31 32 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 30 def total_7d @total_7d end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 33 def self.attribute_map { :'failed_7d' => :'failed_7d', :'pending_7d' => :'pending_7d', :'provider_id' => :'provider_id', :'rejected_7d' => :'rejected_7d', :'sent_7d' => :'sent_7d', :'sent_today' => :'sent_today', :'total_7d' => :'total_7d' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 336 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 56 def self.openapi_types { :'failed_7d' => :'Integer', :'pending_7d' => :'Integer', :'provider_id' => :'String', :'rejected_7d' => :'Integer', :'sent_7d' => :'Integer', :'sent_today' => :'Integer', :'total_7d' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 309 def ==(o) return true if self.equal?(o) self.class == o.class && failed_7d == o.failed_7d && pending_7d == o.pending_7d && provider_id == o.provider_id && rejected_7d == o.rejected_7d && sent_7d == o.sent_7d && sent_today == o.sent_today && total_7d == o.total_7d end |
#eql?(o) ⇒ Boolean
323 324 325 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 323 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
329 330 331 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 329 def hash [failed_7d, pending_7d, provider_id, rejected_7d, sent_7d, sent_today, total_7d].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @failed_7d.nil? invalid_properties.push('invalid value for "failed_7d", failed_7d cannot be nil.') end if @failed_7d < 0 invalid_properties.push('invalid value for "failed_7d", must be greater than or equal to 0.') end if @pending_7d.nil? invalid_properties.push('invalid value for "pending_7d", pending_7d cannot be nil.') end if @pending_7d < 0 invalid_properties.push('invalid value for "pending_7d", must be greater than or equal to 0.') end if @provider_id.nil? invalid_properties.push('invalid value for "provider_id", provider_id cannot be nil.') end if @rejected_7d.nil? invalid_properties.push('invalid value for "rejected_7d", rejected_7d cannot be nil.') end if @rejected_7d < 0 invalid_properties.push('invalid value for "rejected_7d", must be greater than or equal to 0.') end if @sent_7d.nil? invalid_properties.push('invalid value for "sent_7d", sent_7d cannot be nil.') end if @sent_7d < 0 invalid_properties.push('invalid value for "sent_7d", must be greater than or equal to 0.') end if @sent_today.nil? invalid_properties.push('invalid value for "sent_today", sent_today cannot be nil.') end if @sent_today < 0 invalid_properties.push('invalid value for "sent_today", must be greater than or equal to 0.') end if @total_7d.nil? invalid_properties.push('invalid value for "total_7d", total_7d cannot be nil.') end if @total_7d < 0 invalid_properties.push('invalid value for "total_7d", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 358 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/sendmux_management_generated/models/provider_usage_item.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @failed_7d.nil? return false if @failed_7d < 0 return false if @pending_7d.nil? return false if @pending_7d < 0 return false if @provider_id.nil? return false if @rejected_7d.nil? return false if @rejected_7d < 0 return false if @sent_7d.nil? return false if @sent_7d < 0 return false if @sent_today.nil? return false if @sent_today < 0 return false if @total_7d.nil? return false if @total_7d < 0 true end |