Class: Sendmux::Management::Generated::Transaction
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Management::Generated::Transaction
- Defined in:
- lib/sendmux_management_generated/models/transaction.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
DECIMAL(19,6) amount.
-
#balance_after ⇒ Object
Returns the value of attribute balance_after.
-
#balance_before ⇒ Object
Returns the value of attribute balance_before.
-
#created_at ⇒ Object
ISO 8601 timestamp.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Transaction public ID.
-
#quantity ⇒ Object
Item count (for USAGE transactions).
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Transaction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Transaction
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::Transaction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::Transaction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'balance_after') self.balance_after = attributes[:'balance_after'] else self.balance_after = nil end if attributes.key?(:'balance_before') self.balance_before = attributes[:'balance_before'] else self.balance_before = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] else self.quantity = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end end |
Instance Attribute Details
#amount ⇒ Object
DECIMAL(19,6) amount
19 20 21 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 19 def amount @amount end |
#balance_after ⇒ Object
Returns the value of attribute balance_after.
21 22 23 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 21 def balance_after @balance_after end |
#balance_before ⇒ Object
Returns the value of attribute balance_before.
23 24 25 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 23 def balance_before @balance_before end |
#created_at ⇒ Object
ISO 8601 timestamp
26 27 28 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 26 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
28 29 30 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 28 def description @description end |
#id ⇒ Object
Transaction public ID
31 32 33 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 31 def id @id end |
#quantity ⇒ Object
Item count (for USAGE transactions)
34 35 36 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 34 def quantity @quantity end |
#type ⇒ Object
Returns the value of attribute type.
36 37 38 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 36 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 61 def self.attribute_map { :'amount' => :'amount', :'balance_after' => :'balance_after', :'balance_before' => :'balance_before', :'created_at' => :'created_at', :'description' => :'description', :'id' => :'id', :'quantity' => :'quantity', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 294 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 103 104 105 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 99 def self.openapi_nullable Set.new([ :'balance_after', :'balance_before', :'quantity', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 85 def self.openapi_types { :'amount' => :'String', :'balance_after' => :'String', :'balance_before' => :'String', :'created_at' => :'String', :'description' => :'String', :'id' => :'String', :'quantity' => :'Float', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 266 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && balance_after == o.balance_after && balance_before == o.balance_before && created_at == o.created_at && description == o.description && id == o.id && quantity == o.quantity && type == o.type end |
#eql?(o) ⇒ Boolean
281 282 283 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 281 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 287 def hash [amount, balance_after, balance_before, created_at, description, id, quantity, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 174 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/sendmux_management_generated/models/transaction.rb', line 202 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @amount.nil? return false if @created_at.nil? return false if @description.nil? return false if @id.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["PURCHASE", "USAGE", "AUTO_TOPUP", "REFUND", "ADJUSTMENT", "unknown_default_open_api"]) return false unless type_validator.valid?(@type) true end |