Class: Sendmux::Management::Generated::WebhookSubscription
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Management::Generated::WebhookSubscription
- Defined in:
- lib/sendmux_management_generated/models/webhook_subscription.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_at ⇒ Object
ISO 8601 creation timestamp.
-
#enabled ⇒ Object
When false, no events are delivered to this subscription.
-
#event_types ⇒ Object
Event types this subscription receives.
-
#failing ⇒ Object
True when the 24-hour retry window has been exhausted for this subscription.
-
#filters ⇒ Object
Returns the value of attribute filters.
-
#id ⇒ Object
Webhook public ID.
-
#name ⇒ Object
Optional human-friendly label used in dashboard list/detail pages.
-
#updated_at ⇒ Object
ISO 8601 last-modified timestamp.
-
#url ⇒ Object
HTTPS endpoint that receives signed event POSTs.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookSubscription
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookSubscription
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::WebhookSubscription` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::WebhookSubscription`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = nil end if attributes.key?(:'event_types') if (value = attributes[:'event_types']).is_a?(Array) self.event_types = value end else self.event_types = nil end if attributes.key?(:'failing') self.failing = attributes[:'failing'] else self.failing = nil end if attributes.key?(:'filters') self.filters = attributes[:'filters'] else self.filters = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end end |
Instance Attribute Details
#created_at ⇒ Object
ISO 8601 creation timestamp
19 20 21 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 19 def created_at @created_at end |
#enabled ⇒ Object
When false, no events are delivered to this subscription.
22 23 24 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 22 def enabled @enabled end |
#event_types ⇒ Object
Event types this subscription receives.
25 26 27 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 25 def event_types @event_types end |
#failing ⇒ Object
True when the 24-hour retry window has been exhausted for this subscription. Reset by updating the subscription (e.g. fixing the URL) and re-enabling.
28 29 30 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 28 def failing @failing end |
#filters ⇒ Object
Returns the value of attribute filters.
30 31 32 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 30 def filters @filters end |
#id ⇒ Object
Webhook public ID
33 34 35 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 33 def id @id end |
#name ⇒ Object
Optional human-friendly label used in dashboard list/detail pages. May be ‘null` for subscriptions created without a name.
36 37 38 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 36 def name @name end |
#updated_at ⇒ Object
ISO 8601 last-modified timestamp
39 40 41 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 39 def updated_at @updated_at end |
#url ⇒ Object
HTTPS endpoint that receives signed event POSTs.
42 43 44 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 42 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 67 def self.attribute_map { :'created_at' => :'created_at', :'enabled' => :'enabled', :'event_types' => :'event_types', :'failing' => :'failing', :'filters' => :'filters', :'id' => :'id', :'name' => :'name', :'updated_at' => :'updated_at', :'url' => :'url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 342 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 111 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 107 def self.openapi_nullable Set.new([ :'name', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 92 def self.openapi_types { :'created_at' => :'String', :'enabled' => :'Boolean', :'event_types' => :'Array<String>', :'failing' => :'Boolean', :'filters' => :'WebhookFilters', :'id' => :'String', :'name' => :'String', :'updated_at' => :'String', :'url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 313 def ==(o) return true if self.equal?(o) self.class == o.class && created_at == o.created_at && enabled == o.enabled && event_types == o.event_types && failing == o.failing && filters == o.filters && id == o.id && name == o.name && updated_at == o.updated_at && url == o.url end |
#eql?(o) ⇒ Boolean
329 330 331 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 329 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 335 def hash [created_at, enabled, event_types, failing, filters, id, name, updated_at, url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 188 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end if @event_types.nil? invalid_properties.push('invalid value for "event_types", event_types cannot be nil.') end if @failing.nil? invalid_properties.push('invalid value for "failing", failing cannot be nil.') end if @filters.nil? invalid_properties.push('invalid value for "filters", filters cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/sendmux_management_generated/models/webhook_subscription.rb', line 228 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @created_at.nil? return false if @enabled.nil? return false if @event_types.nil? return false if @failing.nil? return false if @filters.nil? return false if @id.nil? return false if @updated_at.nil? return false if @url.nil? true end |