Class: Sendmux::Management::Generated::WebhookUpdateBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Sendmux::Management::Generated::WebhookUpdateBody
- Defined in:
- lib/sendmux_management_generated/models/webhook_update_body.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#enabled ⇒ Object
When toggled from false to true, also clears the ‘failing` flag — retry deliveries resume on the next matching event.
-
#event_types ⇒ Object
Replaces the full event-type list.
-
#filters ⇒ Object
Replaces the full delivery scope.
-
#name ⇒ Object
Replace the human-friendly label.
-
#url ⇒ Object
New HTTPS endpoint.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookUpdateBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookUpdateBody
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendmux::Management::Generated::WebhookUpdateBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendmux::Management::Generated::WebhookUpdateBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'event_types') if (value = attributes[:'event_types']).is_a?(Array) self.event_types = value end end if attributes.key?(:'filters') self.filters = attributes[:'filters'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'url') self.url = attributes[:'url'] end end |
Instance Attribute Details
#enabled ⇒ Object
When toggled from false to true, also clears the ‘failing` flag — retry deliveries resume on the next matching event.
19 20 21 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 19 def enabled @enabled end |
#event_types ⇒ Object
Replaces the full event-type list. At least one must be provided.
22 23 24 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 22 def event_types @event_types end |
#filters ⇒ Object
Replaces the full delivery scope. Omit to leave unchanged; pass an empty mailbox_ids array for all team mailboxes.
25 26 27 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 25 def filters @filters end |
#name ⇒ Object
Replace the human-friendly label. Send ‘null` to clear it; omit to leave unchanged.
28 29 30 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 28 def name @name end |
#url ⇒ Object
New HTTPS endpoint. Must be https://.
31 32 33 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 31 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 56 def self.attribute_map { :'enabled' => :'enabled', :'event_types' => :'event_types', :'filters' => :'filters', :'name' => :'name', :'url' => :'url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 195 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 92 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 88 def self.openapi_nullable Set.new([ :'name', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 77 def self.openapi_types { :'enabled' => :'Boolean', :'event_types' => :'Array<String>', :'filters' => :'WebhookFilters', :'name' => :'String', :'url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && enabled == o.enabled && event_types == o.event_types && filters == o.filters && name == o.name && url == o.url end |
#eql?(o) ⇒ Boolean
182 183 184 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 182 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 188 def hash [enabled, event_types, filters, name, url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@event_types.nil? && @event_types.length < 1 invalid_properties.push('invalid value for "event_types", number of items must be greater than or equal to 1.') end if !@name.nil? && @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 156 |
# File 'lib/sendmux_management_generated/models/webhook_update_body.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@event_types.nil? && @event_types.length < 1 return false if !@name.nil? && @name.to_s.length > 255 true end |